@@ -1,5 +1,5 @@
 /* Locating a program in PATH.
-   Copyright (C) 2001-2004, 2006-2023 Free Software Foundation, Inc.
+   Copyright (C) 2001-2004, 2006-2026 Free Software Foundation, Inc.
    Written by Bruno Haible <haible@clisp.cons.org>, 2001.
 
    This file is free software: you can redistribute it and/or modify
@@ -47,16 +47,12 @@ find_in_path (const char *progname)
   return progname;
 #else
   /* Unix */
-  char *path;
-  char *path_rest;
-  char *cp;
-
   if (strchr (progname, '/') != NULL)
     /* If progname contains a slash, it is either absolute or relative to
        the current directory.  PATH is not used.  */
     return progname;
 
-  path = getenv ("PATH");
+  char *path = getenv ("PATH");
   if (path == NULL || *path == '\0')
     /* If PATH is not set, the default search path is implementation
        dependent.  */
@@ -71,17 +67,14 @@ find_in_path (const char *progname)
     /* Out of memory.  */
     return progname;
 # endif
-  for (path_rest = path; ; path_rest = cp + 1)
+  for (char *path_rest = path; ; )
     {
-      const char *dir;
-      bool last;
-      char *progpathname;
-
       /* Extract next directory in PATH.  */
-      dir = path_rest;
+      const char *dir = path_rest;
+      char *cp;
       for (cp = path_rest; *cp != '\0' && *cp != ':'; cp++)
         ;
-      last = (*cp == '\0');
+      bool last = (*cp == '\0');
       *cp = '\0';
 
       /* Empty PATH components designate the current directory.  */
@@ -89,6 +82,7 @@ find_in_path (const char *progname)
         dir = ".";
 
       /* Concatenate dir and progname.  */
+      char *progpathname;
 # if !IN_FINDPROG_LGPL
       progpathname = xconcatenated_filename (dir, progname, NULL);
 # else
@@ -114,7 +108,7 @@ find_in_path (const char *progname)
               && ! S_ISDIR (statbuf.st_mode))
             {
               /* Found!  */
-              if (strcmp (progpathname, progname) == 0)
+              if (streq (progpathname, progname))
                 {
                   free (progpathname);
 
@@ -146,6 +140,8 @@ find_in_path (const char *progname)
 
       if (last)
         break;
+
+      path_rest = cp + 1;
     }
 
   /* Not found in PATH.  An error will be signalled at the first call.  */
