@@ -1,5 +1,5 @@
 /* Test of next_prime() function.
-   Copyright (C) 2025 Free Software Foundation, Inc.
+   Copyright (C) 2025-2026 Free Software Foundation, Inc.
 
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -26,9 +26,10 @@
 int
 main ()
 {
-  ASSERT (next_prime (1) == 11);
-  ASSERT (next_prime (3) == 11);
-  ASSERT (next_prime (7) == 11);
+  ASSERT (next_prime (1) >= 1 && next_prime (1) <= 11);
+  ASSERT (next_prime (3) >= 3 && next_prime (3) <= 11);
+  ASSERT (next_prime (5) >= 5 && next_prime (5) <= 11);
+  ASSERT (next_prime (7) >= 7 && next_prime (7) <= 11);
   ASSERT (next_prime (10) == 11);
   ASSERT (next_prime (11) == 11);
   ASSERT (next_prime (12) == 13);
