@@ -1,6 +1,5 @@
 /* Reading PO files.
-   Copyright (C) 1995-2024 Free Software Foundation, Inc.
-   This file was written by Peter Miller <millerp@canb.auug.org.au>
+   Copyright (C) 1995-2026 Free Software Foundation, Inc.
 
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -15,14 +14,15 @@
    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <https://www.gnu.org/licenses/>.  */
 
-#ifdef HAVE_CONFIG_H
-# include <config.h>
-#endif
+/* Written by Peter Miller, Ulrich Drepper, and Bruno Haible.  */
+
+#include <config.h>
 
 /* Specification.  */
 #include "read-catalog-file.h"
 
 #include "open-catalog.h"
+#include "str-list.h"
 #include "xerror-handler.h"
 
 
@@ -31,10 +31,12 @@ read_catalog_file (const char *filename, catalog_input_format_ty input_syntax)
 {
   char *real_filename;
   FILE *fp = open_catalog_file (filename, &real_filename, true);
-  msgdomain_list_ty *result;
 
-  result = read_catalog_stream (fp, real_filename, filename, input_syntax,
-                                textmode_xerror_handler);
+  string_list_ty arena;
+  string_list_init (&arena);
+  msgdomain_list_ty *result =
+    read_catalog_stream (fp, real_filename, filename, input_syntax,
+                         textmode_xerror_handler, &arena);
 
   if (fp != stdin)
     fclose (fp);
