@@ -1,7 +1,5 @@
 /* xgettext GSettings schema file backend.
-   Copyright (C) 2002-2003, 2006, 2013, 2015 Free Software Foundation,
-   Inc.
-   Written by Daiki Ueno <ueno@gnu.org>, 2013.
+   Copyright (C) 2002-2026 Free Software Foundation, Inc.
 
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -14,7 +12,9 @@
    GNU General Public License for more details.
 
    You should have received a copy of the GNU General Public License
-   along with this program.  If not, see <http://www.gnu.org/licenses/>.  */
+   along with this program.  If not, see <https://www.gnu.org/licenses/>.  */
+
+/* Written by Daiki Ueno.  */
 
 
 #include <stdio.h>
@@ -28,17 +28,13 @@ extern "C" {
 #endif
 
 
-#define EXTENSIONS_GSETTINGS \
-  { "gschema.xml", "gsettings" }, \
+/* The scanner is implemented as ITS rules, in its/gsettings.its.  */
+
+#define EXTENSIONS_GSETTINGS                    \
+  { "gschema.xml", NULL }, \
 
 #define SCANNERS_GSETTINGS \
-  { "gsettings", extract_gsettings, NULL, NULL, NULL, NULL }, \
-
-/* Scan a gsettings XML file and add its translatable strings to mdlp.  */
-extern void extract_gsettings (FILE *fp, const char *real_filename,
-                               const char *logical_filename,
-                               flag_context_list_table_ty *flag_table,
-                               msgdomain_list_ty *mdlp);
+  { "gsettings", NULL, NULL, NULL, NULL, NULL }, \
 
 
 #ifdef __cplusplus
