@@ -1,6 +1,5 @@
 /* Output stream that produces HTML output.
-   Copyright (C) 2006-2009, 2019-2020 Free Software Foundation, Inc.
-   Written by Bruno Haible <bruno@clisp.org>, 2006.
+   Copyright (C) 2006-2026 Free Software Foundation, Inc.
 
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -15,6 +14,8 @@
    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <https://www.gnu.org/licenses/>.  */
 
+/* Written by Bruno Haible.  */
+
 #include <config.h>
 
 /* Specification.  */
@@ -128,9 +129,7 @@ emit_pending_spans (html_ostream_t stream, bool shrink_stack)
 {
   if (stream->curr_class_stack_size > stream->last_class_stack_size)
     {
-      size_t i;
-
-      for (i = stream->last_class_stack_size; i < stream->curr_class_stack_size; i++)
+      for (size_t i = stream->last_class_stack_size; i < stream->curr_class_stack_size; i++)
         {
           char *classname = (char *) gl_list_get_at (stream->class_stack, i);
 
@@ -142,9 +141,7 @@ emit_pending_spans (html_ostream_t stream, bool shrink_stack)
     }
   else if (stream->curr_class_stack_size < stream->last_class_stack_size)
     {
-      size_t i;
-
-      for (i = stream->last_class_stack_size; i > stream->curr_class_stack_size; i--)
+      for (size_t i = stream->last_class_stack_size; i > stream->curr_class_stack_size; i--)
         ostream_write_str (stream->destination, "</span>");
       stream->last_class_stack_size = stream->curr_class_stack_size;
       if (shrink_stack)
@@ -162,9 +159,7 @@ html_ostream::write_mem (html_ostream_t stream, const void *data, size_t len)
     {
       #define BUFFERSIZE 2048
       char inbuffer[BUFFERSIZE];
-      size_t inbufcount;
-
-      inbufcount = stream->buflen;
+      size_t inbufcount = stream->buflen;
       if (inbufcount > 0)
         memcpy (inbuffer, stream->buf, inbufcount);
       for (;;)
@@ -190,16 +185,14 @@ html_ostream::write_mem (html_ostream_t stream, const void *data, size_t len)
 
             while (insize > 0)
               {
-                unsigned char c0;
-                ucs4_t uc;
-                int nbytes;
-
-                c0 = ((const unsigned char *) inptr)[0];
+                unsigned char c0 = ((const unsigned char *) inptr)[0];
                 if (insize < (c0 < 0xc0 ? 1 : c0 < 0xe0 ? 2 : c0 < 0xf0 ? 3 :
                               c0 < 0xf8 ? 4 : c0 < 0xfc ? 5 : 6))
                   break;
 
-                nbytes = u8_mbtouc (&uc, (const unsigned char *) inptr, insize);
+                ucs4_t uc;
+                int nbytes =
+                  u8_mbtouc (&uc, (const unsigned char *) inptr, insize);
 
                 if (uc == '\n')
                   {
@@ -424,7 +417,6 @@ html_ostream_t
 html_ostream_create (ostream_t destination)
 {
   html_ostream_t stream = XMALLOC (struct html_ostream_representation);
-
   stream->base.vtable = &html_ostream_vtable;
   stream->destination = destination;
   stream->hyperlink_ref = NULL;
@@ -436,3 +428,19 @@ html_ostream_create (ostream_t destination)
 
   return stream;
 }
+
+/* Accessors.  */
+
+static ostream_t
+html_ostream::get_destination (html_ostream_t stream)
+{
+  return stream->destination;
+}
+
+/* Instanceof test.  */
+
+bool
+is_instance_of_html_ostream (ostream_t stream)
+{
+  return IS_INSTANCE (stream, ostream, html_ostream);
+}
